==> seedsui-react-2.6.2.tgz: package/es/Emoji/Emoji.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { createPortal } from 'react-dom';
import Carrousel from './../Carrousel';
import InputPre from './../InputPre';
import Button from './../Button';
import Instance from './instance.js';
import data from './instance.data.js';

if (!window._seeds_lang) window._seeds_lang = {}; // 国际化数据

var Emoji = (_temp = _class = function (_Component) {
  _inherits(Emoji, _Component);

  function Emoji(props) {
    _classCallCheck(this, Emoji);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.componentDidUpdate = function (prevProps) {
      // 自动获取焦点
      if (_this.props.autoFocus && prevProps.show !== _this.props.show && _this.props.show === true && _this.$inputPre) {
        _this.$inputPre.$input.focus();
      }
    };

    _this.componentDidMount = function () {
      if (_this.props.autoFocus && _this.$inputPre) _this.$inputPre.$input.focus();
      if (_this.instance) return;
      var instance = new Instance({
        data: _this.props.data,

        mask: _this.$el,
        isClickMaskHide: _this.props.isClickMaskHide,
        onClickMask: _this.onClickMask,

        onClickSubmit: _this.onClickSubmit,

        onChange: _this.props.onChange
      });
      _this.instance = instance;
    };

    _this.onClickMask = function (s, e) {
      if (_this.props.onClickMask) _this.props.onClickMask(Object.getArgs(e, _this.props.args));
    };

    _this.onClickSubmit = function (value, s, e) {
      if (_this.props.onClickSubmit) _this.props.onClickSubmit(value, Object.getArgs(e, _this.props.args));
    };

    _this.getFaceDOM = function () {
      var data = _this.props.data;
      // icons分页变量

      var icons = [];
      var page = 0;
      var index = 0;
      var count = 23;
      // icons分页
      for (var name in data) {
        if (index !== 0 && index % count === 0) {
          page++;
        }
        if (!icons[page]) icons[page] = [];
        icons[page].push({ key: name, value: data[name] });
        index++;
      }
      // 生成DOM
      return icons.map(function (icon, i) {
        return React.createElement(
          'div',
          { key: 'page' + i, className: 'emoji-carrousel-slide' },
          icon.map(function (item, index) {
            return React.createElement(
              'a',
              { key: 'face' + index, className: 'emoji-face', 'data-emoji': item.value, title: item.key },
              '\xA0'
            );
          }),
          React.createElement(
            'a',
            { className: 'emoji-face-delete' },
            '\xA0'
          )
        );
      });
    };

    return _this;
  }
  // 遮罩

  // 提交按钮

  // 表情


  Emoji.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        show = _props.show,
        data = _props.data,
        portal = _props.portal,
        args = _props.args,
        autoFocus = _props.autoFocus,
        value = _props.value,
        placeholder = _props.placeholder,
        isClickMaskHide = _props.isClickMaskHide,
        onClickMask = _props.onClickMask,
        maskClassName = _props.maskClassName,
        maskStyle = _props.maskStyle,
        className = _props.className,
        style = _props.style,
        licon = _props.licon,
        onChange = _props.onChange,
        submitCaption = _props.submitCaption,
        submitStyle = _props.submitStyle,
        submitClassName = _props.submitClassName,
        onClickSubmit = _props.onClickSubmit,
        others = _objectWithoutProperties(_props, ['show', 'data', 'portal', 'args', 'autoFocus', 'value', 'placeholder', 'isClickMaskHide', 'onClickMask', 'maskClassName', 'maskStyle', 'className', 'style', 'licon', 'onChange', 'submitCaption', 'submitStyle', 'submitClassName', 'onClickSubmit']);

    return createPortal(React.createElement(
      'div',
      { ref: function ref(el) {
          _this2.$el = el;
        }, className: 'mask emoji-mask' + (show ? ' active' : '') + (maskClassName ? ' ' + maskClassName : ''), style: maskStyle, onClick: this.onClickMask },
      React.createElement(
        'div',
        { ref: function ref(el) {
            _this2.$container = el;
          }, className: 'emoji active' + (className ? ' ' + className : ''), style: style, onClick: this.onClick },
        licon,
        React.createElement(
          'div',
          { className: 'emoji-edit' },
          React.createElement(InputPre, _extends({
            ref: function ref(el) {
              _this2.$inputPre = el;
            },
            className: 'emoji-edit-input',
            inputStyle: { padding: '0' },
            valueBindProp: true,
            value: value,
            onChange: onChange,
            placeholder: placeholder
          }, others)),
          React.createElement('i', { ref: function ref(el) {
              _this2.$icon = el;
            }, className: 'icon emoji-edit-icon' }),
          React.createElement(
            Button,
            { className: 'emoji-edit-submit' + (submitClassName ? ' ' + submitClassName : ''), style: submitStyle, disabled: !value },
            submitCaption
          )
        ),
        React.createElement(
          Carrousel,
          { ref: function ref(el) {
              _this2.$carrousel = el;
            }, pagination: true, className: 'carrousel-container emoji-carrousel', style: { display: 'none' } },
          this.getFaceDOM()
        )
      )
    ), this.props.portal || document.getElementById('root'));
  };

  return Emoji;
}(Component), _class.defaultProps = {
  autoFocus: false,
  data: data,
  placeholder: window._seeds_lang['say_something'] || '说点什么吧...',
  isClickMaskHide: false,
  submitCaption: window._seeds_lang['submit'] || '提交'
}, _temp);
export { Emoji as default };
Emoji.propTypes = process.env.NODE_ENV !== "production" ? {
  show: PropTypes.bool, // ios内核必须隐藏, 不能移除dom, 弹出时才不会有bug, 所以必须用show
  data: PropTypes.object,

  portal: PropTypes.object,
  args: PropTypes.any,

  autoFocus: PropTypes.bool,

  value: PropTypes.string,
  placeholder: PropTypes.string,

  isClickMaskHide: PropTypes.bool,
  onClickMask: PropTypes.func,

  maskClassName: PropTypes.string,
  maskStyle: PropTypes.object,

  className: PropTypes.string,
  style: PropTypes.object,

  licon: PropTypes.node,

  onChange: PropTypes.func,

  submitStyle: PropTypes.object,
  submitClassName: PropTypes.string,
  submitCaption: PropTypes.node,
  onClickSubmit: PropTypes.func
} : {};

==> seedsui-react-2.7.2.tgz: package/es/Emoji/Emoji.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { createPortal } from 'react-dom';
import Carrousel from './../Carrousel';
import InputPre from './../InputPre';
import Button from './../Button';
import Instance from './instance.js';
import data from './instance.data.js';

if (!window._seeds_lang) window._seeds_lang = {}; // 国际化数据

var Emoji = (_temp = _class = function (_Component) {
  _inherits(Emoji, _Component);

  function Emoji(props) {
    _classCallCheck(this, Emoji);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.componentDidUpdate = function (prevProps) {
      // 自动获取焦点
      if (_this.props.autoFocus && prevProps.show !== _this.props.show && _this.props.show === true && _this.$inputPre) {
        _this.$inputPre.$input.focus();
      }
    };

    _this.componentDidMount = function () {
      if (_this.props.autoFocus && _this.$inputPre) _this.$inputPre.$input.focus();
      if (_this.instance) return;
      var _this$props = _this.props,
          _this$props$maskAttri = _this$props.maskAttribute,
          maskAttribute = _this$props$maskAttri === undefined ? {} : _this$props$maskAttri,
          _this$props$submitAtt = _this$props.submitAttribute,
          submitAttribute = _this$props$submitAtt === undefined ? {} : _this$props$submitAtt;

      _this.instance = new Instance({
        data: _this.props.data,

        mask: _this.$el,
        isClickMaskHide: false,
        onClickMask: maskAttribute.onClick || null,

        onClickSubmit: submitAttribute.onClick || null,

        onChange: _this.props.onChange
      });
    };

    _this.getFaceDOM = function () {
      var data = _this.props.data;
      // icons分页变量

      var icons = [];
      var page = 0;
      var index = 0;
      var count = 23;
      // icons分页
      for (var name in data) {
        if (index !== 0 && index % count === 0) {
          page++;
        }
        if (!icons[page]) icons[page] = [];
        icons[page].push({ key: name, value: data[name] });
        index++;
      }
      // 生成DOM
      return icons.map(function (icon, i) {
        return React.createElement(
          'div',
          { key: 'page' + i, className: 'emoji-carrousel-slide' },
          icon.map(function (item, index) {
            return React.createElement(
              'a',
              { key: 'face' + index, className: 'emoji-face', 'data-emoji': item.value, title: item.key },
              '\xA0'
            );
          }),
          React.createElement(
            'a',
            { className: 'emoji-face-delete' },
            '\xA0'
          )
        );
      });
    };

    return _this;
  }
  // 表情


  Emoji.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        portal = _props.portal,
        show = _props.show,
        data = _props.data,
        autoFocus = _props.autoFocus,
        value = _props.value,
        placeholder = _props.placeholder,
        _props$maskAttribute = _props.maskAttribute,
        maskAttribute = _props$maskAttribute === undefined ? {} : _props$maskAttribute,
        _props$submitAttribut = _props.submitAttribute,
        submitAttribute = _props$submitAttribut === undefined ? {} : _props$submitAttribut,
        _props$inputAttribute = _props.inputAttribute,
        inputAttribute = _props$inputAttribute === undefined ? {} : _props$inputAttribute,
        _props$liconAttribute = _props.liconAttribute,
        liconAttribute = _props$liconAttribute === undefined ? {} : _props$liconAttribute,
        licon = _props.licon,
        onChange = _props.onChange,
        others = _objectWithoutProperties(_props, ['portal', 'show', 'data', 'autoFocus', 'value', 'placeholder', 'maskAttribute', 'submitAttribute', 'inputAttribute', 'liconAttribute', 'licon', 'onChange']);

    return createPortal(React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, maskAttribute, { className: 'mask emoji-mask' + (show ? ' active' : '') + (maskAttribute.className ? ' ' + maskAttribute.className : '') }),
      React.createElement(
        'div',
        _extends({}, others, { className: 'emoji active' + (others.className ? ' ' + others.className : '') }),
        licon,
        liconAttribute && liconAttribute.className && React.createElement('i', _extends({}, liconAttribute, { className: 'icon' + (liconAttribute.className ? ' ' + liconAttribute.className : '') })),
        React.createElement(
          'div',
          { className: 'emoji-edit' },
          React.createElement(InputPre, _extends({
            ref: function ref(el) {
              _this2.$inputPre = el;
            },
            className: 'emoji-edit-input',
            inputStyle: { padding: '0' },
            valueBindProp: true,
            value: value,
            onChange: onChange,
            placeholder: placeholder
          }, inputAttribute)),
          React.createElement('i', { ref: function ref(el) {
              _this2.$icon = el;
            }, className: 'icon emoji-edit-icon' }),
          React.createElement(
            Button,
            _extends({}, submitAttribute, { className: 'emoji-edit-submit' + (submitAttribute.className ? ' ' + submitAttribute.className : ''), disabled: !value }),
            submitAttribute.caption || window._seeds_lang['submit'] || '提交'
          )
        ),
        React.createElement(
          Carrousel,
          { ref: function ref(el) {
              _this2.$carrousel = el;
            }, pagination: true, className: 'carrousel-container emoji-carrousel', style: { display: 'none' } },
          this.getFaceDOM()
        )
      )
    ), portal || document.getElementById('root') || document.body);
  };

  return Emoji;
}(Component), _class.defaultProps = {
  autoFocus: false,
  data: data,
  placeholder: window._seeds_lang['say_something'] || '说点什么吧...'
}, _temp);
export { Emoji as default };
Emoji.propTypes = process.env.NODE_ENV !== "production" ? {
  portal: PropTypes.object,
  show: PropTypes.bool, // ios内核必须隐藏, 不能移除dom, 弹出时才不会有bug, 所以必须用show
  data: PropTypes.object,

  autoFocus: PropTypes.bool,
  value: PropTypes.string,
  placeholder: PropTypes.string,

  maskAttribute: PropTypes.object,
  submitAttribute: PropTypes.object,
  inputAttribute: PropTypes.object,
  liconAttribute: PropTypes.bool,
  licon: PropTypes.node,

  onChange: PropTypes.func
} : {};
